summaryrefslogtreecommitdiff
path: root/apps
diff options
context:
space:
mode:
authorPeter D'Hoye <peter.dhoye@gmail.com>2007-04-05 20:24:07 +0000
committerPeter D'Hoye <peter.dhoye@gmail.com>2007-04-05 20:24:07 +0000
commitbf92f9c1f6531849008507019043d6b6836bb098 (patch)
tree84029d1fd6e1cd7e4456a2e5cbb993dad56c39a1 /apps
parent1396826a30b4ca2acb4db946dbf42f3f7456a0f0 (diff)
downloadrockbox-bf92f9c1f6531849008507019043d6b6836bb098.zip
rockbox-bf92f9c1f6531849008507019043d6b6836bb098.tar.gz
rockbox-bf92f9c1f6531849008507019043d6b6836bb098.tar.bz2
rockbox-bf92f9c1f6531849008507019043d6b6836bb098.tar.xz
Fix automatic rolo on new version for archos. Introduces new define in config files for bootfile location.
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@13036 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'apps')
-rw-r--r--apps/misc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/apps/misc.c b/apps/misc.c
index 0a31339..4e1de7a 100644
--- a/apps/misc.c
+++ b/apps/misc.c
@@ -890,12 +890,12 @@ void check_bootfile(bool do_rolo)
DIR* dir = NULL;
struct dirent* entry = NULL;
- /* 1. open ROCKBOX_DIR and find the BOOTFILE dir entry */
- dir = opendir(ROCKBOX_DIR);
+ /* 1. open BOOTDIR and find the BOOTFILE dir entry */
+ dir = opendir(BOOTDIR);
if(!dir) return; /* do we want an error splash? */
- /* loop all files in ROCKBOX_DIR */
+ /* loop all files in BOOTDIR */
while(0 != (entry = readdir(dir)))
{
if(!strcasecmp(entry->d_name, BOOTFILE))
@@ -911,7 +911,7 @@ void check_bootfile(bool do_rolo)
struct text_message message={ lines, 2 };
button_clear_queue(); /* Empty the keyboard buffer */
if(gui_syncyesno_run(&message, NULL, NULL) == YESNO_YES)
- rolo_load(ROCKBOX_DIR "/" BOOTFILE);
+ rolo_load(BOOTDIR "/" BOOTFILE);
}
}
boot_size = entry->size;